@@ -8,26 +8,19 @@ Created on Oct 10, 2011
 @author: tmetsch
 '''
 
-
-from ctypes import cast, c_char_p, c_int
-from dtrace.consumer import DTraceConsumerThread, deref
+from dtrace import DTraceConsumerThread
+from threading import Thread
 import time
 
 SCRIPT = 'syscall:::entry { @num[zonename] = count(); }'
 
 
-def walk(data, arg):
+def walk(id, key, value):
     '''
     Nice formatted aggregate walker.
     '''
-    tmp = data.contents.dtada_data
 
-    name = cast(tmp + 16, c_char_p).value
-    count = deref(tmp + 272, c_int).value
-
-    print 'Zone "{0:s}" made {1:d} syscalls.'.format(name, count)
-
-    return 0
+    print 'Zone "{0:s}" made {1:d} syscalls.'.format(key[0], value)
 
 
 def main():
@@ -36,14 +29,15 @@ def main():
     '''
     print 'Hint: if you don\'t get any output try running it with pfexec...'
 
-    dtrace = DTraceConsumerThread(SCRIPT, walk_func=walk)
+    consumer = DTraceConsumerThread(SCRIPT, walk_func=walk)
+    dtrace = Thread(target=consumer.run)
     dtrace.start()
 
     # we will stop the thread after some time...
     time.sleep(5)
 
     # stop and wait for join...
-    dtrace.stop()
+    consumer.stop()
     dtrace.join()
 
 if __name__ == '__main__':
