@@ -10,7 +10,8 @@ Created on Oct 10, 2011
 '''
 
 import time
-from dtrace.consumer import DTraceConsumerThread
+from threading import Thread
+from dtrace import DTraceConsumerThread
 
 SCRIPT = 'syscall:::entry { @num[execname] = count(); }'
 
@@ -19,14 +20,15 @@ def main():
     '''
     Run DTrace...
     '''
-    dtrace = DTraceConsumerThread(SCRIPT)
+    consumer = DTraceConsumerThread(SCRIPT)
+    dtrace = Thread(target=consumer.run)
     dtrace.start()
 
     # we will stop the thread after some time...
     time.sleep(2)
 
     # stop and wait for join...
-    dtrace.stop()
+    consumer.stop()
     dtrace.join()
 
 if __name__ == '__main__':
